==> jcublas-0.9.0-sources.jar: jcuda/jcublas/cublasOperation.java <==
/*
 * JCublas - Java bindings for CUBLAS, the NVIDIA CUDA BLAS library,
 * to be used with JCuda
 *
 * Copyright (c) 2010-2015 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcublas;

/**
 * Indicates which operation needs to be performed with the
 * dense matrix.
 */
public class cublasOperation
{
    /**
     * The non-transpose operation is selected
     */
    public static final int CUBLAS_OP_N = 0;

    /**
     * The transpose operation is selected
     */
    public static final int CUBLAS_OP_T = 1;

    /**
     * The conjugate transpose operation is selected
     */
    public static final int CUBLAS_OP_C = 2;

    /**
     * Private constructor to prevent instantiation
     */
    private cublasOperation(){}

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUBLAS_OP_N: return "CUBLAS_OP_N";
            case CUBLAS_OP_T: return "CUBLAS_OP_T";
            case CUBLAS_OP_C: return "CUBLAS_OP_C";
        }
        return "INVALID cublasOperation: "+n;
    }
}

==> jcublas-10.2.0-sources.jar: jcuda/jcublas/cublasOperation.java <==
/*
 * JCublas - Java bindings for CUBLAS, the NVIDIA CUDA BLAS library,
 * to be used with JCuda
 *
 * Copyright (c) 2010-2015 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcublas;

/**
 * Indicates which operation needs to be performed with the
 * dense matrix.
 */
public class cublasOperation
{
    /**
     * The non-transpose operation is selected
     */
    public static final int CUBLAS_OP_N = 0;

    /**
     * The transpose operation is selected
     */
    public static final int CUBLAS_OP_T = 1;

    /**
     * The conjugate transpose operation is selected
     */
    public static final int CUBLAS_OP_C = 2;
    
    /**
     * Synonym if CUBLAS_OP_C
     */
    public static final int CUBLAS_OP_HERMITAN = 2;
    
    /**
     * Conjugate 
     */
    public static final int CUBLAS_OP_CONJG = 3; 

    /**
     * Private constructor to prevent instantiation
     */
    private cublasOperation(){}

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUBLAS_OP_N: return "CUBLAS_OP_N";
            case CUBLAS_OP_T: return "CUBLAS_OP_T";
            case CUBLAS_OP_C: return "CUBLAS_OP_C/CUBLAS_OP_HERMITAN";
            case CUBLAS_OP_CONJG: return "CUBLAS_OP_CONJG";
        }
        return "INVALID cublasOperation: "+n;
    }
}
